from setuptools import setup

setup(name='distributionsbi',
      
      version='0.1',
      
      description='Gaussian and binomial distributions',
      
      packages=['distributionsbi'],
      
      author='Pratik Patil',
      
      author_email='pratikmpatil12@gmail.com',
      
      zip_safe=False)
